summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/coordit.h
diff options
context:
space:
mode:
authorAdam Borowski <kilobyte@angband.pl>2010-11-04 12:02:39 +0100
committerAdam Borowski <kilobyte@angband.pl>2010-11-04 12:02:39 +0100
commitc438898a13c1211d5e0a935089df0973595a66cd (patch)
tree15cd6826aa4960c29f3e45bdd678a4f25126455b /crawl-ref/source/coordit.h
parent5463161aea273fe8090bbc5aca200983bfc2f3a6 (diff)
downloadcrawl-ref-c438898a13c1211d5e0a935089df0973595a66cd.tar.gz
crawl-ref-c438898a13c1211d5e0a935089df0973595a66cd.zip
s/spiral_iterator/equidistant_iterator/g (dpeg)
Diffstat (limited to 'crawl-ref/source/coordit.h')
-rw-r--r--crawl-ref/source/coordit.h10
1 files changed, 5 insertions, 5 deletions
diff --git a/crawl-ref/source/coordit.h b/crawl-ref/source/coordit.h
index 184d368623..dbfff64b01 100644
--- a/crawl-ref/source/coordit.h
+++ b/crawl-ref/source/coordit.h
@@ -88,15 +88,15 @@ public:
radius_iterator(pos, 1, C_SQUARE, NULL, _exclude_center) {}
};
/* spiral_iterator: Iterates over coordinates in integer ranges. Unlike other
* iterators, it tries hard to not favorize any particular
* direction (unless fair = false, when it saves some CPU).
*/
-class spiral_iterator :
+class equidistant_iterator :
public std::iterator<std::forward_iterator_tag, coord_def>
{
public:
- spiral_iterator(const coord_def& _center,
+ equidistant_iterator(const coord_def& _center,
bool _fair = true,
bool exclude_center = true,
int _max_radius = 107);
@@ -104,8 +104,8 @@ public:
coord_def operator *() const;
const coord_def* operator->() const;
- const spiral_iterator& operator ++();
- spiral_iterator operator ++(int);
+ const equidistant_iterator& operator ++();
+ equidistant_iterator operator ++(int);
private:
coord_def center, current;
std::vector<coord_def> lists[3], *vcur, *vnear, *vfar;
@@ -88,15 +88,15 @@ public:
radius_iterator(pos, 1, C_SQUARE, NULL, _exclude_center) {}
};
-/* spiral_iterator: Iterates over coordinates in integer ranges. Unlike other
+/* equidistant_iterator: Iterates over coordinates in integer ranges. Unlike other
* iterators, it tries hard to not favorize any particular
* direction (unless fair = false, when it saves some CPU).